@@ -1,9 +1,11 @@
 #' tidyndr: A package for analyzing the de-identified patient-level data from the
 #' Nigeria National Data Repository (NDR)
 #'
-#' To learn more about tidyndr, refer to \code{browseVignettes(package = "tidyndr")}
+#' @description
+#' To learn more about tidyndr, refer to the vignettes: \code{browseVignettes(package = "tidyndr")}
 #'
 #' @docType package
 #' @keywords internal
 #' @name tidyndr
+"_PACKAGE"
 NULL
