@@ -3,6 +3,8 @@ test_that("tx_regimen works", {
     tx_regimen(ndr_example, status = "default"),
     ndr_example %>%
       subset(current_status_28_days == "Active" &
+               !patient_has_died %in% TRUE &
+             !patient_transferred_out %in% TRUE &
         dplyr::if_else(
           current_age <= 3,
           last_regimen %in% c(
