@@ -9,9 +9,11 @@ test_that("tx_rtt works", {
   )
 
   expect_identical(
-    tx_rtt(old_data, new_data = ndr_example, status = "default"),
+    tx_rtt(new_data = ndr_example, old_data, status = "default"),
     ndr_example %>%
       subset(current_status_28_days == "Active" &
+               !patient_has_died %in% TRUE &
+             !patient_transferred_out %in% TRUE &
         patient_identifier %in% losses$patient_identifier)
   )
 })
